#######################################################################
#                                                                     #
#                                 Pph                                 #
#                                                                     #
#                    The Portable Project Handler                     #
#                                                                     #
#               EPI Pomdapi, INRIA Paris - Rocquencourt               #
#                                                                     #
#  Copyright 2005-2014 INRIA.                                         #
#  Institut National de Recherche en Informatique et en Automatique.  #
#  All rights reserved. This file is distributed only by permission.  #
#                                                                     #
#  Francois Clement <Francois.Clement@inria.fr>                       #
#  Pierre Weis <Pierre.Weis@inria.fr>                                 #
#                                                                     #
#######################################################################

# $Id: configure_process_options.profile,v 1.4 2014-01-31 16:17:08 fclement Exp $

# User configuration option processing profile.

# Load user configuration settings, if it exists and is nonempty.
PROFILE="${USER_CONFIGURE_SETTINGS_PROFILE:?}"
if test -s "$PROFILE"; then
    . "$PROFILE"
fi

# Initiate the filling of user configuration file.
init_config_file "${USER_CONFIGURE_SETTINGS_NO_EXT:?}"
IER=$?
if test $IER -ne 0; then exit $IER; fi

#
# Process compiler options.
#
report_message "Setting compiler bindings in ${USER_CONFIGURE_SETTINGS_BNAME:?}"

# Set the command search path.
COMMAND_SEARCH_PATH=`get_command_search_path`
IER=$?
if test $IER -ne 0; then exit $IER; fi

# For each, if required, take first intrinsic default, then value from user
# configuration file, and finally, from the command line.

# C preprocessor/compiler.
C_PREPROCESSOR=`\
  get_command "${PROJECT_C_PREPROCESSOR_STATUS:?}"\
              "${C_PREPROCESSOR_INTRINSIC_DEFAULT_LIST:?}"\
              "$C_PREPROCESSOR"\
              "$C_PREPROCESSOR_FROM_COMMAND_LINE"\
              "$COMMAND_SEARCH_PATH" ""`
IER=$?
if test $IER -ne 0; then exit $IER; fi
case "${C_PREPROCESSOR:?}" in
( False | Not_found ) :;;
( */cpp | */cpp-* ) :;;
( * )
    error "unsupported C preprocessor \"$C_PREPROCESSOR\""
    remedy "Please report."
    exit ${UNSUPPORTED_CASE_ERROR:?}
esac

C_COMPILER=`\
  get_command "${PROJECT_C_COMPILER_STATUS:?}"\
              "${C_COMPILER_INTRINSIC_DEFAULT_LIST:?}"\
              "$C_COMPILER"\
              "$C_COMPILER_FROM_COMMAND_LINE"\
              "$COMMAND_SEARCH_PATH" ""`
IER=$?
if test $IER -ne 0; then exit $IER; fi
case "${C_COMPILER:?}" in
( False | Not_found ) :;;
( */gcc | */*gcc-* )
    C_FLAGS_COMPILER_SPECIFIC="${GCC_FLAGS_COMPILER_SPECIFIC:?}"
    case `$C_COMPILER --version` in
    ( *3.3.6* ) C_FLAGS_ALL_WARNINGS="${GCC_FLAGS_ALL_WARNINGS_GCC336:?}";;
    ( * ) C_FLAGS_ALL_WARNINGS="${GCC_FLAGS_ALL_WARNINGS:?}";;
    esac
    C_FLAGS_WARN_ERROR="${GCC_FLAGS_WARN_ERROR:?}"
    ;;
( */icc | */icc-* )
    C_FLAGS_COMPILER_SPECIFIC="${ICC_FLAGS_COMPILER_SPECIFIC:?}"
    C_FLAGS_ALL_WARNINGS="${ICC_FLAGS_ALL_WARNINGS:?}"
    C_FLAGS_WARN_ERROR="${ICC_FLAGS_WARN_ERROR:?}"
    ;;
( */cc | */cc-* )
    C_FLAGS_COMPILER_SPECIFIC="${CC_FLAGS_COMPILER_SPECIFIC:?}"
    C_FLAGS_ALL_WARNINGS="${CC_FLAGS_ALL_WARNINGS:?}"
    C_FLAGS_WARN_ERROR="${CC_FLAGS_WARN_ERROR:?}"
    ;;
( * )
    error "unsupported C compiler \"$C_COMPILER\""
    remedy "Please report."
    exit ${UNSUPPORTED_CASE_ERROR:?}
esac

# C++ preprocessor/compiler.
CPP_PREPROCESSOR=`\
  get_command "${PROJECT_CPP_PREPROCESSOR_STATUS:?}"\
              "${CPP_PREPROCESSOR_INTRINSIC_DEFAULT_LIST:?}"\
              "$CPP_PREPROCESSOR"\
              "$CPP_PREPROCESSOR_FROM_COMMAND_LINE"\
              "$COMMAND_SEARCH_PATH" ""`
IER=$?
if test $IER -ne 0; then exit $IER; fi
case "${CPP_PREPROCESSOR:?}" in
( False | Not_found ) :;;
( */cpp | */cpp-* ) :;;
( * )
    error "unsupported C++ preprocessor \"$CPP_PREPROCESSOR\""
    remedy "Please report."
    exit ${UNSUPPORTED_CASE_ERROR:?}
esac

CPP_COMPILER=`\
  get_command "${PROJECT_CPP_COMPILER_STATUS:?}"\
              "${CPP_COMPILER_INTRINSIC_DEFAULT_LIST:?}"\
              "$CPP_COMPILER"\
              "$CPP_COMPILER_FROM_COMMAND_LINE"\
              "$COMMAND_SEARCH_PATH" ""`
IER=$?
if test $IER -ne 0; then exit $IER; fi
case "${CPP_COMPILER:?}" in
( False | Not_found ) :;;
( */g++ | */*g++-* )
    CPP_FLAGS_COMPILER_SPECIFIC="${GPP_FLAGS_COMPILER_SPECIFIC:?}"
    CPP_FLAGS_ALL_WARNINGS="${GPP_FLAGS_ALL_WARNINGS:?}"
    CPP_FLAGS_WARN_ERROR="${GPP_FLAGS_WARN_ERROR:?}"
    ;;
( */icpc | */icpc-* )
    CPP_FLAGS_COMPILER_SPECIFIC="${ICPC_FLAGS_COMPILER_SPECIFIC:?}"
    CPP_FLAGS_ALL_WARNINGS="${ICPC_FLAGS_ALL_WARNINGS:?}"
    CPP_FLAGS_WARN_ERROR="${ICPC_FLAGS_WARN_ERROR:?}"
    ;;
( * )
    error "unsupported C++ compiler \"$CPP_COMPILER\""
    remedy "Please report."
    exit ${UNSUPPORTED_CASE_ERROR:?}
esac

# Fortran preprocessor/compiler.
FORTRAN_PREPROCESSOR=`\
  get_command "${PROJECT_FORTRAN_PREPROCESSOR_STATUS:?}"\
              "${FORTRAN_PREPROCESSOR_INTRINSIC_DEFAULT_LIST:?}"\
              "$FORTRAN_PREPROCESSOR"\
              "$FORTRAN_PREPROCESSOR_FROM_COMMAND_LINE"\
              "$COMMAND_SEARCH_PATH" ""`
IER=$?
if test $IER -ne 0; then exit $IER; fi
case "${FORTRAN_PREPROCESSOR:?}" in
( False | Not_found ) :;;
( */cpp | */cpp-* )
    FORTRAN_PREPROCESSOR_FLAGS_SPECIFIC="\
${CPP_FORTRAN_PREPROCESSOR_FLAGS_SPECIFIC:?}"
    ;;
( */fpp | */fpp-* )
    FORTRAN_PREPROCESSOR_FLAGS_SPECIFIC="\
${FPP_FORTRAN_PREPROCESSOR_FLAGS_SPECIFIC:?}"
    ;;
( * )
    error "unsupported Fortran preprocessor \"$FORTRAN_PREPROCESSOR\""
    remedy "Please report."
    exit ${UNSUPPORTED_CASE_ERROR:?}
esac

FORTRAN_COMPILER=`\
  get_command "${PROJECT_FORTRAN_COMPILER_STATUS:?}"\
              "${FORTRAN_COMPILER_INTRINSIC_DEFAULT_LIST:?}"\
              "$FORTRAN_COMPILER"\
              "$FORTRAN_COMPILER_FROM_COMMAND_LINE"\
              "$COMMAND_SEARCH_PATH" ""`
IER=$?
if test $IER -ne 0; then exit $IER; fi
case "${FORTRAN_COMPILER:?}" in
( False | Not_found ) :;;
( */gfortran | */*gfortran-* )
    FORTRAN_FLAGS_COMPILER_SPECIFIC="${GFORTRAN_FLAGS_COMPILER_SPECIFIC:?}"
    FORTRAN_FLAGS_ALL_WARNINGS="${GFORTRAN_FLAGS_ALL_WARNINGS:?}"
    FORTRAN_FLAGS_WARN_ERROR="${GFORTRAN_FLAGS_WARN_ERROR:?}"
    ;;
( */ifort | */ifort-* )
    FORTRAN_FLAGS_COMPILER_SPECIFIC="${IFORT_FLAGS_COMPILER_SPECIFIC:?}"
    FORTRAN_FLAGS_ALL_WARNINGS="${IFORT_FLAGS_ALL_WARNINGS:?}"
    FORTRAN_FLAGS_WARN_ERROR="${IFORT_FLAGS_WARN_ERROR:?}"
    ;;
( */g77 | */g77-* )
    FORTRAN_FLAGS_COMPILER_SPECIFIC="${G77_FLAGS_COMPILER_SPECIFIC:?}"
    FORTRAN_FLAGS_ALL_WARNINGS="${G77_FLAGS_ALL_WARNINGS:?}"
    FORTRAN_FLAGS_WARN_ERROR="${G77_FLAGS_WARN_ERROR:?}"
    ;;
( */g95 | */g95-* )
    FORTRAN_FLAGS_COMPILER_SPECIFIC="${G95_FLAGS_COMPILER_SPECIFIC:?}"
    FORTRAN_FLAGS_ALL_WARNINGS="${G95_FLAGS_ALL_WARNINGS:?}"
    FORTRAN_FLAGS_WARN_ERROR="${G95_FLAGS_WARN_ERROR:?}"
    ;;
( */f77 | */f77-* )
    FORTRAN_FLAGS_COMPILER_SPECIFIC="${F77_FLAGS_COMPILER_SPECIFIC:?}"
    FORTRAN_FLAGS_ALL_WARNINGS="${F77_FLAGS_ALL_WARNINGS:?}"
    FORTRAN_FLAGS_WARN_ERROR="${F77_FLAGS_WARN_ERROR:?}"
    ;;
( * )
    error "unsupported Fortran compiler \"$FORTRAN_COMPILER\""
    remedy "Please report."
    exit ${UNSUPPORTED_CASE_ERROR:?}
esac

# Java compiler.
JAVA_COMPILER=`\
  get_command "${PROJECT_JAVA_COMPILER_STATUS:?}"\
              "${JAVA_COMPILER_INTRINSIC_DEFAULT_LIST:?}"\
              "$JAVA_COMPILER"\
              "$JAVA_COMPILER_FROM_COMMAND_LINE"\
              "$COMMAND_SEARCH_PATH" ""`
IER=$?
if test $IER -ne 0; then exit $IER; fi
case "${JAVA_COMPILER:?}" in
( False | Not_found ) :;;
( */gcj | */*gcj-* )
    JAVA_FLAGS_COMPILER_SPECIFIC="${GCJ_FLAGS_COMPILER_SPECIFIC:?}"
    JAVA_FLAGS_ALL_WARNINGS="${GCJ_FLAGS_ALL_WARNINGS:?}"
    JAVA_FLAGS_WARN_ERROR="${GCJ_FLAGS_WARN_ERROR:?}"
    ;;
( */javac | */javac-* )
    JAVA_FLAGS_COMPILER_SPECIFIC="${JAVAC_FLAGS_COMPILER_SPECIFIC:?}"
    JAVA_FLAGS_ALL_WARNINGS="${JAVAC_FLAGS_ALL_WARNINGS:?}"
    JAVA_FLAGS_WARN_ERROR="${JAVAC_FLAGS_WARN_ERROR:?}"
    ;;
( * )
    error "unsupported Java compiler \"$JAVA_COMPILER\""
    remedy "Please report."
    exit ${UNSUPPORTED_CASE_ERROR:?}
esac

# Moca compiler.
MOCA_COMPILER=`\
  get_command "${PROJECT_MOCA_COMPILER_STATUS:?}"\
              "mocac"\
              "$MOCA_COMPILER"\
              "$MOCA_COMPILER_FROM_COMMAND_LINE"\
              "$COMMAND_SEARCH_PATH" ""`
IER=$?
if test $IER -ne 0; then exit $IER; fi
case "${MOCA_COMPILER:?}" in
( False | Not_found ) :;;
( */mocac | */mocac-* ) :;;
( * )
    error "unsupported Moca compiler \"$MOCA_COMPILER\""
    remedy "Please report."
    exit ${UNSUPPORTED_CASE_ERROR:?}
esac

# OCaml preprocessor/compilers/other commands.
if test -z "$OCAML_COMMAND_SEARCH_PATH"; then
    OCAML_COMMAND_SEARCH_PATH="$COMMAND_SEARCH_PATH"
fi
if test -n "$OCAML_COMMAND_SEARCH_PATH_FROM_COMMAND_LINE"; then
    OCAML_COMMAND_SEARCH_PATH=`absolute_command_search_path \
                               $OCAML_COMMAND_SEARCH_PATH_FROM_COMMAND_LINE`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
fi

OCAML_PREPROCESSOR=`\
  get_command "${PROJECT_OCAML_PREPROCESSOR_STATUS:?}"\
              "${OCAML_PREPROCESSOR_INTRINSIC_DEFAULT_LIST:?}"\
              "$OCAML_PREPROCESSOR"\
              "$OCAML_PREPROCESSOR_FROM_COMMAND_LINE"\
              "$OCAML_COMMAND_SEARCH_PATH" ".opt"`
IER=$?
if test $IER -ne 0; then exit $IER; fi
case "${OCAML_PREPROCESSOR:?}" in
( False | Not_found )
    CAMLP4_FLAGS="False"
    CAMLP5_FLAGS="False"
    ;;
( */camlp4* | */camlp5* )
    OCAML_COMMAND_SEARCH_PATH=`$DIRNAME $OCAML_PREPROCESSOR` && \
    OCAML_PREPROCESSOR_WHERE=`$OCAML_PREPROCESSOR -where` && \
    OCAML_PREPROCESSOR_BASENAME=`$BASENAME $OCAML_PREPROCESSOR_WHERE`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
    OCAML_PREPROCESSOR_INCLUDES="-I +$OCAML_PREPROCESSOR_BASENAME"
    case "${OCAML_PREPROCESSOR_BASENAME:?}" in
    ( camlp4 ) OCAML_PP_FLAGS="\${CAMLP4_FLAGS}";;
    ( camlp5 ) OCAML_PP_FLAGS="\${CAMLP5_FLAGS}";;
    esac
    ;;
( * )
    error "unsupported OCaml preprocessor \"$OCAML_PREPROCESSOR\""
    remedy "Please report."
    exit ${UNSUPPORTED_CASE_ERROR:?}
esac

OCAML_COMPILATION_TARGETS=""
OCAML_COMPILATION_EXTENSIONS=""
OCAML_BYT_COMPILER=`\
  get_command "${PROJECT_OCAML_BYT_COMPILER_STATUS:?}"\
              "ocamlc"\
              "$OCAML_BYT_COMPILER"\
              "$OCAML_BYT_COMPILER_FROM_COMMAND_LINE"\
              "$OCAML_COMMAND_SEARCH_PATH" ".opt"`
IER=$?
if test $IER -ne 0; then exit $IER; fi
case "${OCAML_BYT_COMPILER:?}" in
( False | Not_found ) :;;
( */ocamlc* )
    OCAML_COMMAND_SEARCH_PATH=`$DIRNAME $OCAML_BYT_COMPILER` && \
    OCAML_WHERE=`$OCAML_BYT_COMPILER -where`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
    OCAML_COMPILATION_TARGETS="$OCAML_COMPILATION_TARGETS byt"
    OCAML_COMPILATION_EXTENSIONS="$OCAML_COMPILATION_EXTENSIONS .byt"
    ;;
( * )
    error "unsupported OCaml byte code compiler \"$OCAML_BYT_COMPILER\""
    remedy "Please report."
    exit ${UNSUPPORTED_CASE_ERROR:?}
esac
OCAML_BIN_COMPILER=`\
  get_command "${PROJECT_OCAML_BIN_COMPILER_STATUS:?}"\
              "ocamlopt"\
              "$OCAML_BIN_COMPILER"\
              "$OCAML_BIN_COMPILER_FROM_COMMAND_LINE"\
              "$OCAML_COMMAND_SEARCH_PATH" ".opt"`
IER=$?
if test $IER -ne 0; then exit $IER; fi
case "${OCAML_BIN_COMPILER:?}" in
( False | Not_found ) :;;
( */ocamlopt* )
    OCAML_COMMAND_SEARCH_PATH=`$DIRNAME $OCAML_BIN_COMPILER`
    OCAML_WHERE=`$OCAML_BIN_COMPILER -where`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
    OCAML_COMPILATION_TARGETS="$OCAML_COMPILATION_TARGETS bin"
    OCAML_COMPILATION_EXTENSIONS="$OCAML_COMPILATION_EXTENSIONS .bin"
    ;;
( * )
    error "unsupported OCaml native code compiler \"$OCAML_BIN_COMPILER\""
    remedy "Please report."
    exit ${UNSUPPORTED_CASE_ERROR:?}
    ;;
esac

PROJECT_OCAML_DEP_DOC_TOP_STATUS="Optional"
if test "${PROJECT_OCAML_BYT_COMPILER_STATUS:?}" = "None" && \
   test "${PROJECT_OCAML_BIN_COMPILER_STATUS:?}" = "None"; then
    PROJECT_OCAML_DEP_DOC_TOP_STATUS="None"
    OCAML_WHERE="False"
    OCAML_COMPILATION_TARGETS="False"
    OCAML_COMPILATION_EXTENSIONS="False"
    if test ${PROJECT_OCAML_OTHER_COMMANDS_STATUS:?} = "None"; then
        OCAML_COMMAND_SEARCH_PATH="False"
    fi
fi

OCAML_DEP_GENERATOR=`\
  get_command "${PROJECT_OCAML_DEP_DOC_TOP_STATUS:?}"\
              "ocamldep"\
              "$OCAML_DEP_GENERATOR"\
              ""\
              "$OCAML_COMMAND_SEARCH_PATH" ".opt"`
IER=$?
if test $IER -ne 0; then exit $IER; fi
OCAML_DOC_GENERATOR=`\
  get_command "${PROJECT_OCAML_DEP_DOC_TOP_STATUS:?}"\
              "ocamldoc"\
              "$OCAML_DOC_GENERATOR"\
              ""\
              "$OCAML_COMMAND_SEARCH_PATH" ".opt"`
IER=$?
if test $IER -ne 0; then exit $IER; fi
OCAML_TOP_GENERATOR=`\
  get_command "${PROJECT_OCAML_DEP_DOC_TOP_STATUS:?}"\
              "ocamlmktop"\
              "$OCAML_TOP_GENERATOR"\
              ""\
              "$OCAML_COMMAND_SEARCH_PATH" ".opt"`
IER=$?
if test $IER -ne 0; then exit $IER; fi
OCAML_LIBRARIAN=`\
  get_command "${PROJECT_OCAML_OTHER_COMMANDS_STATUS:?}"\
              "ocamlmklib"\
              "$OCAML_LIBRARIAN"\
              ""\
              "$OCAML_COMMAND_SEARCH_PATH" ".opt"`
IER=$?
if test $IER -ne 0; then exit $IER; fi
OCAML_LEX_GENERATOR=`\
  get_command "${PROJECT_OCAML_OTHER_COMMANDS_STATUS:?}"\
              "ocamllex"\
              "$OCAML_LEX_GENERATOR"\
              ""\
              "$OCAML_COMMAND_SEARCH_PATH" ".opt"`
IER=$?
if test $IER -ne 0; then exit $IER; fi
OCAML_YAC_GENERATOR=`\
  get_command "${PROJECT_OCAML_OTHER_COMMANDS_STATUS:?}"\
              "ocamlyacc"\
              "$OCAML_YAC_GENERATOR"\
              ""\
              "$OCAML_COMMAND_SEARCH_PATH" ".opt"`
IER=$?
if test $IER -ne 0; then exit $IER; fi

# Store the current settings for compilers.
add_to_config_file \
    "${USER_CONFIGURE_SETTINGS_NO_EXT:?}" \
    "C preprocessor" "C_PREPROCESSOR" "$C_PREPROCESSOR" \
    "C compiler" "C_COMPILER" "$C_COMPILER" \
    "C compiler specific option" \
      "    C_FLAGS_COMPILER_SPECIFIC" "$C_FLAGS_COMPILER_SPECIFIC" \
    "C all-warnings option" \
      "    C_FLAGS_ALL_WARNINGS" "$C_FLAGS_ALL_WARNINGS" \
    "C warnings-are-errors option" \
      "    C_FLAGS_WARN_ERROR" "$C_FLAGS_WARN_ERROR" \
    "C++ preprocessor" "CPP_PREPROCESSOR" "$CPP_PREPROCESSOR" \
    "C++ compiler" "CPP_COMPILER" "$CPP_COMPILER" \
    "C++ compiler specific option" \
      "    CPP_FLAGS_COMPILER_SPECIFIC" "$CPP_FLAGS_COMPILER_SPECIFIC" \
    "C++ all-warnings option" \
      "    CPP_FLAGS_ALL_WARNINGS" "$CPP_FLAGS_ALL_WARNINGS" \
    "C++ warnings-are-errors option" \
      "    CPP_FLAGS_WARN_ERROR" "$CPP_FLAGS_WARN_ERROR" \
    "Fortran preprocessor" "FORTRAN_PREPROCESSOR" "$FORTRAN_PREPROCESSOR" \
    "Fortran preprocessor specific option" \
      "    FORTRAN_PREPROCESSOR_FLAGS_SPECIFIC" \
      "$FORTRAN_PREPROCESSOR_FLAGS_SPECIFIC" \
    "Fortran compiler" "FORTRAN_COMPILER" "$FORTRAN_COMPILER" \
    "Fortran compiler specific option" \
      "    FORTRAN_FLAGS_COMPILER_SPECIFIC" "$FORTRAN_FLAGS_COMPILER_SPECIFIC" \
    "Fortran all-warnings option" \
      "    FORTRAN_FLAGS_ALL_WARNINGS" "$FORTRAN_FLAGS_ALL_WARNINGS" \
    "Fortran warnings-are-errors option" \
      "    FORTRAN_FLAGS_WARN_ERROR" "$FORTRAN_FLAGS_WARN_ERROR" \
    "Java compiler" "JAVA_COMPILER" "$JAVA_COMPILER" \
    "Java compiler specific option" \
      "    JAVA_FLAGS_COMPILER_SPECIFIC" "$JAVA_FLAGS_COMPILER_SPECIFIC" \
    "Java all-warnings option" \
      "    JAVA_FLAGS_ALL_WARNINGS" "$JAVA_FLAGS_ALL_WARNINGS" \
    "Java warnings-are-errors option" \
      "    JAVA_FLAGS_WARN_ERROR" "$JAVA_FLAGS_WARN_ERROR" \
    "Moca compiler" "MOCA_COMPILER" "$MOCA_COMPILER" \
    "OCaml preprocessor" "OCAML_PREPROCESSOR" "$OCAML_PREPROCESSOR" \
    "OCaml preprocessor includes" \
      "    OCAML_PREPROCESSOR_INCLUDES" "$OCAML_PREPROCESSOR_INCLUDES" \
    "Camlp4 options" "    CAMLP4_FLAGS" "$CAMLP4_FLAGS" \
    "Camlp5 options" "    CAMLP5_FLAGS" "$CAMLP5_FLAGS" \
    "OCaml preprocessor options" "    OCAML_PP_FLAGS" "$OCAML_PP_FLAGS" \
    "OCaml command search path" \
      "OCAML_COMMAND_SEARCH_PATH" "$OCAML_COMMAND_SEARCH_PATH" \
    "OCaml standard library location" "OCAML_WHERE" "$OCAML_WHERE" \
    "OCaml dependencies generator" \
      "OCAML_DEP_GENERATOR" "$OCAML_DEP_GENERATOR" \
    "OCaml byte compiler" "OCAML_BYT_COMPILER" "$OCAML_BYT_COMPILER" \
    "OCaml native compiler" "OCAML_BIN_COMPILER" "$OCAML_BIN_COMPILER" \
    "OCaml compilation targets" \
      "    OCAML_COMPILATION_TARGETS" "$OCAML_COMPILATION_TARGETS" \
    "OCaml compilation extensions" \
      "    OCAML_COMPILATION_EXTENSIONS" "$OCAML_COMPILATION_EXTENSIONS" \
    "OCaml documentation generator" \
      "OCAML_DOC_GENERATOR" "$OCAML_DOC_GENERATOR" \
    "OCaml top-level generator" "OCAML_TOP_GENERATOR" "$OCAML_TOP_GENERATOR" \
    "OCaml librarian" "OCAML_LIBRARIAN" "$OCAML_LIBRARIAN" \
    "OCaml lexer generator" "OCAML_LEX_GENERATOR" "$OCAML_LEX_GENERATOR" \
    "OCaml parser generator" "OCAML_YAC_GENERATOR" "$OCAML_YAC_GENERATOR"
IER=$?
if test $IER -ne 0; then exit $IER; fi

#
# Process installation root directory option.
#
set_configuration_binding \
    "installation root directory" \
    "INSTALL_ROOT_DIR" "absolute_file_path-not_here" \
    "${USER_CONFIGURE_SETTINGS_NO_EXT:?}" \
    "${INSTALL_ROOT_DIR_INTRINSIC_DEFAULT:?}" \
    "$INSTALL_ROOT_DIR" \
    "$INSTALL_ROOT_DIR_FROM_COMMAND_LINE"

#
# Process private tool option.
#
set_configuration_binding \
    "private tool" "PRIVATE_TOOL" "bool" \
    "${USER_CONFIGURE_SETTINGS_NO_EXT:?}" \
    "${PRIVATE_TOOL_INTRINSIC_DEFAULT:?}" \
    "$PRIVATE_TOOL" \
    "$PRIVATE_TOOL_FROM_COMMAND_LINE"

set_configuration_binding \
    "mimic installation root directory" \
    "    MIMIC_INSTALL_ROOT_DIR" "absolute_file_path" \
    "${USER_CONFIGURE_SETTINGS_NO_EXT:?}" \
    "${MIMIC_INSTALL_ROOT_DIR_INTRINSIC_DEFAULT:?}" \
    "$MIMIC_INSTALL_ROOT_DIR" \
    "$MIMIC_INSTALL_ROOT_DIR_FROM_COMMAND_LINE"

if test -d "${PROJECT_TARBALLS_DIR:?}"; then
    set_configuration_binding \
        "tarballs installation root directory" \
        "    TARBALLS_INSTALL_ROOT_DIR" \
        "absolute_file_path-tarballs_install_root_dir" \
        "${USER_CONFIGURE_SETTINGS_NO_EXT:?}" \
        "${TARBALLS_INSTALL_ROOT_DIR_INTRINSIC_DEFAULT:?}" \
        "$TARBALLS_INSTALL_ROOT_DIR" \
        ""
    set_configuration_binding \
        "tarballs mimic installation root directory" \
        "    TARBALLS_MIMIC_INSTALL_ROOT_DIR" \
        "absolute_file_path-tarballs_mimic_install_root_dir" \
        "${USER_CONFIGURE_SETTINGS_NO_EXT:?}" \
        "${TARBALLS_MIMIC_INSTALL_ROOT_DIR_INTRINSIC_DEFAULT:?}" \
        "$TARBALLS_MIMIC_INSTALL_ROOT_DIR" \
        ""
fi

#
# Process additional options if any.
#
if ${PROJECT_CONFIGURATION_ADDITIONAL_OPTIONS:?}; then
    process_additional_options
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
fi

# Register new user configuration settings.
register_config_file "${USER_CONFIGURE_SETTINGS_NO_EXT:?}"
IER=$?
if test $IER -ne 0; then exit $IER; fi

# Echo user configuration settings.
# Check for the existence of nonempty variables outside backquotes.
DB="${USER_CONFIGURE_SETTINGS_PPH:?}"
if ! test -f "$DB"; then
    error "nonexistent configuration file \"$DB\""
    exit ${NONEXISTENT_FILE_ERROR:?}
fi
if ${PRIVATE_TOOL:?} || ${DEVEL_MODE:?}; then
    DB_CONTENTS=`$EGREP -v '^#|^$' $DB`
else
    DB_CONTENTS=`\
      $EGREP -v \
        '^#|^$|PRIVATE_TOOL =|(TARBALLS|MIMIC)[A-Z_]*_INSTALL_ROOT_DIR =' $DB`
fi
$CAT << eof 1>&2

Configuration settings for project $PROJECT_NAME.

Version: $PROJECT_VERSION_FULL_INFO

$DB_CONTENTS

eof
